@@ -2,34 +2,22 @@ package Class::Usul;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.68.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.69.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants  qw( FALSE TRUE );
-use Class::Usul::Functions  qw( data_dumper env_prefix );
-use Class::Usul::Types      qw( Bool ConfigProvider HashRef Localiser
-                                LoadableClass Locker Logger );
+use Class::Usul::Functions  qw( data_dumper ns_environment );
+use Class::Usul::Types      qw( Bool ConfigProvider HashRef
+                                Localiser LoadableClass Locker Logger );
 use Moo;
 
 # Attribute constructors
 my $_build_debug = sub {
-   my $self = shift; my $k = (env_prefix $self->config->appclass).'_DEBUG';
-
-   return !$ENV{ $k } ? FALSE : TRUE;
-};
-
-my $_build_lock = sub {
-   my $self = shift; my $attr = { %{ $self->config->lock_attributes } };
-
-   $attr->{debug  } = $self->debug;
-   $attr->{log    } = $self->log;
-   $attr->{tempdir} = $self->config->tempdir;
-
-   return $self->lock_class->new( $attr );
+   return !!ns_environment( $_[ 0 ]->config->appclass, 'debug' ) ? TRUE : FALSE;
 };
 
 # Public attributes
-has 'config'       => is => 'lazy', isa => ConfigProvider, builder => sub {
-   $_[ 0 ]->config_class->new( $_[ 0 ]->_config_attr ) },
+has 'config'       => is => 'lazy', isa => ConfigProvider,
+   builder         => sub { $_[ 0 ]->config_class->new( $_[ 0 ]->_config_attr)},
    init_arg        => undef;
 
 has '_config_attr' => is => 'ro',   isa => HashRef, builder => sub { {} },
@@ -47,7 +35,8 @@ has 'l10n'         => is => 'lazy', isa => Localiser,
 has 'l10n_class'   => is => 'lazy', isa => LoadableClass, coerce => TRUE,
    default         => 'Class::Usul::L10N';
 
-has 'lock'         => is => 'lazy', isa => Locker, builder => $_build_lock;
+has 'lock'         => is => 'lazy', isa => Locker,
+   builder         => sub { $_[ 0 ]->lock_class->new( builder => $_[ 0 ] ) };
 
 has 'lock_class'   => is => 'lazy', isa => LoadableClass, coerce => TRUE,
    default         => 'IPC::SRLock';
@@ -85,7 +74,7 @@ Class::Usul - A base class providing config, locking, logging, and l10n
 
 =head1 Version
 
-Describes Class::Usul version v0.68.$Rev: 1 $
+Describes Class::Usul version v0.69.$Rev: 1 $
 
 =head1 Synopsis
 
